==> telega-8.x-1.23.tar.gz: telega/src/Utility/RedisStoreTrait.php <==
<?php

namespace Drupal\telega\Utility;

/**
 * Redis Store Trait.
 */
trait RedisStoreTrait {

  /**
   * Start Cconversation.
   */
  public function startConversation() {
    $conversation = $this->getName();
    return $this->setVal('conversation', $conversation);
  }

  /**
   * Stop conversation.
   */
  public function stopConversation() {
    return $this->setVal('conversation', "");
  }

  /**
   * Set Val to Redis.
   */
  public function setVal(string $name, int|string $val) : string | NULL {
    $root = $this->getRoot();
    $key = "$root:$name";
    if (\Drupal::hasService('redis')) {
      return \Drupal::service('redis')->set($key, $val);
    }
    else {
      \Drupal::cache()->set("telega::$key", $val);
    }
    return NULL;
  }

  /**
   * Get value From Redis.
   */
  public function getVal(string $name) : string | NULL {
    $root = $this->getRoot();
    $key = "$root:$name";
    if (\Drupal::hasService('redis')) {
      return \Drupal::service('redis')->get($key);
    }
    else {
      \Drupal::cache()->get("telega::$key");
    }
    return NULL;
  }

  /**
   * Root.
   */
  public function getRoot() : string {
    // $bot_id = $this->telegram->getBotId();
    $message = $this->getMessage();
    $bot_name = $this->telegram->getBotUsername();
    $chat_id = $message->getChat()->getId();
    $user_id = $message->getFrom()->getId();
    $key = $chat_id;
    if ($user_id != $chat_id) {
      $key = "{$chat_id}:{$user_id}";
    }
    return "\$telega:{$bot_name}:{$key}";
  }

}

==> telega-8.x-1.25.tar.gz: telega/src/Utility/RedisStoreTrait.php <==
<?php

namespace Drupal\telega\Utility;

/**
 * Redis Store Trait.
 */
trait RedisStoreTrait {

  /**
   * Store Set.
   */
  private function set(string $key, string $val) {
    if (\Drupal::hasService('redis')) {
      \Drupal::service('redis')->set($key, $val);
    }
    else {
      \Drupal::cache()->set("telega::$key", $val);
    }
  }

  /**
   * Store get.
   */
  private function get(string $key) {
    $result = "";
    if (\Drupal::hasService('redis')) {
      $result = \Drupal::service('redis')->get($key);
    }
    else {
      if ($cache = \Drupal::cache()->get("telega::$key")) {
        $result = $cache->data;
      }
    }
    return $result;
  }

  /**
   * Start Conversation.
   */
  public function startConversation() {
    $conversation = $this->getName();
    return $this->setVal('conversation', $conversation);
  }

  /**
   * Stop conversation.
   */
  public function stopConversation() {
    return $this->setVal('conversation', "");
  }

  /**
   * Set Val to Redis.
   */
  public function setVal(string $name, int|string $val) {
    $root = $this->getRoot();
    $key = "$root:$name";
    $this->set($key, "$val");
  }

  /**
   * Get value From Redis.
   */
  public function getVal(string $name) : NULL | string {
    $root = $this->getRoot();
    $key = "$root:$name";
    return $this->get($key);
  }

  /**
   * Root.
   */
  public function getRoot() : string {
    // $bot_id = $this->telegram->getBotId();
    $message = $this->getMessage();
    $bot_name = $this->telegram->getBotUsername();
    $chat_id = $message->getChat()->getId();
    $user_id = $message->getFrom()->getId();
    $key = $chat_id;
    if ($user_id != $chat_id) {
      $key = "{$chat_id}:{$user_id}";
    }
    return "\$telega:{$bot_name}:{$key}";
  }

}
